@@ -7,6 +7,7 @@ workers.
 import os
 import math
 import time
+import json
 import threading
 import heapq
 from contextlib import ExitStack, suppress
@@ -15,7 +16,7 @@ import botocore
 import WDL
 import WDL.runtime.task_container
 import WDL.runtime._statusbar
-from WDL._util import PygtailLogger, rmtree_atomic, symlink_force
+from WDL._util import rmtree_atomic, symlink_force, write_atomic
 from WDL._util import StructuredLogMessage as _
 from ._util import (
     detect_aws_region,
@@ -65,7 +66,9 @@ class BatchJob(WDL.runtime.task_container.TaskContainer):
                 not cls._fs_id or cls._fs_id == studio_efs_id
             ), "Configured EFS ([aws] fs / MINIWDL__AWS__FS, [aws] fsap / MINIWDL__AWS__FSAP) isn't associated with current SageMaker Studio domain EFS"
             cls._fs_id = studio_efs_id
-            assert cls._fs_mount.rstrip("/") == studio_efs_mount.rstrip("/"), (
+            assert cls._fs_mount.rstrip("/") == studio_efs_mount.rstrip("/") or (
+                cls._fs_mount.startswith(studio_efs_mount).rstrip("/") + "/"
+            ), (
                 "misconfiguration, set [file_io] root / MINIWDL__FILE_IO__ROOT to "
                 + studio_efs_mount.rstrip("/")
             )
@@ -298,22 +301,31 @@ class BatchJob(WDL.runtime.task_container.TaskContainer):
         commands = [
             f"cd {self.container_dir}/work",
             "exit_code=0",
-            "bash ../command >> ../stdout.txt 2> >(tee -a ../stderr.txt >&2) || exit_code=$?",
+            "bash -l ../command >> ../stdout.txt 2> >(tee -a ../stderr.txt >&2) || exit_code=$?",
         ]
         if self.cfg.get_bool("aws", "container_sync"):
             commands.append("find . -type f | xargs sync")
             commands.append("sync ../stdout.txt ../stderr.txt")
         commands.append("exit $exit_code")
 
+        resource_requirements = [
+            {"type": "VCPU", "value": str(vcpu)},
+            {"type": "MEMORY", "value": str(memory_mbytes)},
+        ]
+
+        if self.runtime_values.get("gpu", False):
+            resource_requirements += [{"type": "GPU", "value": "1"}]
+
         container_properties = {
             "image": image_tag,
             "volumes": volumes,
             "mountPoints": mount_points,
             "command": ["/bin/bash", "-ec", "\n".join(commands)],
-            "resourceRequirements": [
-                {"type": "VCPU", "value": str(vcpu)},
-                {"type": "MEMORY", "value": str(memory_mbytes)},
+            "environment": [
+                {"name": ev_name, "value": ev_value}
+                for ev_name, ev_value in self.runtime_values.get("env", dict())
             ],
+            "resourceRequirements": resource_requirements,
             "privileged": self.runtime_values.get("privileged", False),
         }
 
@@ -403,13 +415,15 @@ class BatchJob(WDL.runtime.task_container.TaskContainer):
         """
         describe_period = self.cfg.get_float("aws", "describe_period")
         cleanup.callback((lambda job_id: self._describer.unsubscribe(job_id)), job_id)
-        poll_stderr = cleanup.enter_context(
-            PygtailLogger(logger, self.host_stderr_txt(), callback=self.stderr_callback)
-        )
+        poll_stderr = cleanup.enter_context(self.poll_stderr_context(logger))
         exit_code = None
         while exit_code is None:
             time.sleep(describe_period)
             job_desc = self._describer.describe(aws_batch, job_id, describe_period)
+            write_atomic(
+                json.dumps(job_desc, indent=2, sort_keys=True),
+                os.path.join(self.host_dir, f"awsBatchJobDetail.{job_id}.json"),
+            )
             job_status = job_desc["status"]
             if "container" in job_desc and "logStreamName" in job_desc["container"]:
                 self._logStreamName = job_desc["container"]["logStreamName"]
@@ -427,13 +441,7 @@ class BatchJob(WDL.runtime.task_container.TaskContainer):
                 if job_status == "STARTING" or (
                     job_status == "RUNNING" and "STARTING" not in self._observed_states
                 ):
-                    # TODO: base TaskContainer should handle this, for separation of concerns
-                    cleanup.enter_context(
-                        WDL.runtime._statusbar.task_running(
-                            self.runtime_values.get("cpu", 1),
-                            self.runtime_values.get("memory_reservation", 0),
-                        )
-                    )
+                    cleanup.enter_context(self.task_running_context())
                 if job_status not in (
                     "SUBMITTED",
                     "PENDING",
